gst_plugins_base/gst/tcp/gstmultifdsink.h
branchRCL_3
changeset 29 567bb019e3e3
parent 0 0e761a78d257
child 30 7e817e7e631c
--- a/gst_plugins_base/gst/tcp/gstmultifdsink.h	Wed Mar 31 22:03:18 2010 +0300
+++ b/gst_plugins_base/gst/tcp/gstmultifdsink.h	Tue Aug 31 15:30:33 2010 +0300
@@ -96,21 +96,21 @@
 } GstSyncMethod;
 
 /**
  * GstUnitType:
  * @GST_UNIT_TYPE_UNDEFINED: undefined
  * @GST_UNIT_TYPE_BUFFERS  : buffers
  * @GST_UNIT_TYPE_TIME     : timeunits (in nanoseconds)
  * @GST_UNIT_TYPE_BYTES    : bytes
  *
  * The units used to specify limits.
  */
 typedef enum
 {
-  GST_UNIT_TYPE_UNDEFINED,
-  GST_UNIT_TYPE_BUFFERS,
-  GST_UNIT_TYPE_TIME,
-  GST_UNIT_TYPE_BYTES
-} GstUnitType;
+  GST_TCP_UNIT_TYPE_UNDEFINED,
+  GST_TCP_UNIT_TYPE_BUFFERS,
+  GST_TCP_UNIT_TYPE_TIME,
+  GST_TCP_UNIT_TYPE_BYTES
+} GstTCPUnitType;
 
 /**
  * GstClientStatus:
@@ -162,9 +162,9 @@
 
   /* method to sync client when connecting */
   GstSyncMethod sync_method;
-  GstUnitType   burst_min_unit;
+  GstTCPUnitType   burst_min_unit;
   guint64       burst_min_value;
-  GstUnitType   burst_max_unit;
+  GstTCPUnitType   burst_max_unit;
   guint64       burst_max_value;
 
   GstCaps *caps;                /* caps of last queued buffer */
@@ -208,6 +208,8 @@
 
   GstTCPProtocol protocol;
   guint mtu;
+  gint qos_dscp;
+  gboolean handle_read;
 
   GArray *bufqueue;     /* global queue of buffers */
 
@@ -216,14 +218,14 @@
 
   /* these values are used to check if a client is reading fast
    * enough and to control receovery */
-  GstUnitType unit_type;/* the type of the units */
+  GstTCPUnitType unit_type;/* the type of the units */
   gint64 units_max;       /* max units to queue for a client */
   gint64 units_soft_max;  /* max units a client can lag before recovery starts */
   GstRecoverPolicy recover_policy;
   GstClockTime timeout; /* max amount of nanoseconds to remain idle */
 
   GstSyncMethod def_sync_method;    /* what method to use for connecting clients */
-  GstUnitType   def_burst_unit;
+  GstTCPUnitType   def_burst_unit;
   guint64       def_burst_value;
 
   /* these values are used to control the amount of data
@@ -233,6 +235,8 @@
   gint64 time_min;	/* min time to queue */
   gint   buffers_min;   /* min number of buffers to queue */
 
+  gboolean resend_streamheader; /* resend streamheader if it changes */
+
   /* stats */
   gint buffers_queued;  /* number of queued buffers */
   gint bytes_queued;    /* number of queued bytes */
@@ -247,8 +251,8 @@
   /* element methods */
   void          (*add)          (GstMultiFdSink *sink, int fd);
   void          (*add_full)     (GstMultiFdSink *sink, int fd, GstSyncMethod sync,
-		                 GstUnitType format, guint64 value, 
-				 GstUnitType max_unit, guint64 max_value);
+		                 GstTCPUnitType format, guint64 value, 
+				 GstTCPUnitType max_unit, guint64 max_value);
   void          (*remove)       (GstMultiFdSink *sink, int fd);
   void          (*remove_flush) (GstMultiFdSink *sink, int fd);
   void          (*clear)        (GstMultiFdSink *sink);
@@ -282,8 +286,8 @@
 #endif
 
 void          gst_multi_fd_sink_add_full     (GstMultiFdSink *sink, int fd, GstSyncMethod sync, 
-                                              GstUnitType min_unit, guint64 min_value,
-                                              GstUnitType max_unit, guint64 max_value);
+                                              GstTCPUnitType min_unit, guint64 min_value,
+                                              GstTCPUnitType max_unit, guint64 max_value);
 #ifdef __SYMBIAN32__
 IMPORT_C
 #endif
@@ -96,21 +96,21 @@
 
 /**
- * GstUnitType:
- * @GST_UNIT_TYPE_UNDEFINED: undefined
- * @GST_UNIT_TYPE_BUFFERS  : buffers
- * @GST_UNIT_TYPE_TIME     : timeunits (in nanoseconds)
- * @GST_UNIT_TYPE_BYTES    : bytes
+ * GstTCPUnitType:
+ * @GST_TCP_UNIT_TYPE_UNDEFINED: undefined
+ * @GST_TCP_UNIT_TYPE_BUFFERS  : buffers
+ * @GST_TCP_UNIT_TYPE_TIME     : timeunits (in nanoseconds)
+ * @GST_TCP_UNIT_TYPE_BYTES    : bytes
  *
  * The units used to specify limits.